@@ -1,4 +1,6 @@
 import math
+from time import time
+from collections import Counter
 import numpy as np
 from hnswlib import Index
 
@@ -12,10 +14,12 @@ class VecStore(Index):
         super().__init__(space=space, dim=dim)
         self.fname = fname
         self.initialized = False
+        self.times=Counter()
 
     def load(self):
         """ loads store content from file named "fname" """
         self.load_index(self.fname)
+        self.initialized = True
 
     def save(self):
         """ saves store content to file named "fname" """
@@ -37,6 +41,7 @@ class VecStore(Index):
         self.initialized = True
 
     def __repr__(self):
+        assert self.initialized
         count = self.element_count
         size = self.max_elements
         return f"VecSore(at:{self.fname},dim:{self.dim},has:{count}/{size})"
@@ -45,6 +50,7 @@ class VecStore(Index):
         """
         adds numpy array of numpy vectors to store
         """
+        t1=time()
         self.init()
         if isinstance(xss, list): xss = np.array(xss)
 
@@ -55,6 +61,8 @@ class VecStore(Index):
             N = max(2 * self.max_elements, 2 ** math.ceil(math.log2(N)))
             self.resize_index(N)
         self.add_items(xss)
+        t2=time()
+        self.times['add']+=(t2-t1)
 
     def ids(self):
         """
@@ -66,11 +74,13 @@ class VecStore(Index):
         """
         returns the list or numpy array of vectors in the store
         """
+        assert self.initialized
         return_type = 'list' if as_list else 'numpy'
         return self.get_items(self.ids(), return_type=return_type)
 
     def delete(self, i):
         """ deletes vector of id=i from the store """
+        assert self.initialized
         self.mark_deleted(i)
 
     def query(self, qss, k=3):
@@ -78,22 +88,32 @@ class VecStore(Index):
          returns ids and knn similarity scores for k neares neightbor
          for each numpy vector (ok also in list form) in qss
         """
+        assert self.initialized
         assert isinstance(k, int)
+
         if isinstance(qss, list): qss = np.array(qss)
         distss, vect_idss = self.knn_query(qss, k, filter=None)
+
         return distss, vect_idss
 
     def query_one(self, qs, k=3):
         """
         returns knns for given k as pairss of (vector id,score)
         """
+        t1 = time()
+        assert self.initialized
         dists, vect_ids = self.query([qs], k=k)
-        return list(zip(dists[0], vect_ids[0]))
+        res= list(zip(dists[0], vect_ids[0]))
+        t2 = time()
+        self.times['query_one'] += (t2 - t1)
+        return res
 
     def all_knns(self, k=3, as_weights=True):
         """
         computes k id,dist for all vectors in the store
         """
+        t1=time()
+        assert self.initialized
         k += 1  # as we drove knn to itself
         xss = self.vecs()
 
@@ -109,7 +129,8 @@ class VecStore(Index):
                 pair = int(j), float(d)
                 pairs.append(pair)
             pairss.append(pairs)
-
+        t2 = time()
+        self.times['all_knns'] += (t2 - t1)
         return pairss
 
 
@@ -155,13 +176,15 @@ def test_vecstore():
     r = vs_.query_one(qs)
     print()
     print(r)
+    print('TIMES:',vs.times)
 
     ps = vs_.all_knns()
     print('\nKNN PAIRS:')
     for p in ps:
         print(p)
 
-    print('STORE:', vs_)
+    print('\nSTORE:', vs_)
+    print('TIMES:', vs_.times)
 
 
 if __name__ == "__main__":
